/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.annotations;


import android.view.View;

import androidx.constraintlayout.widget.ConstraintSet;

import com.compdfkit.annotations.databinding.AnnotationPdfSampleActivityBinding;
import com.compdfkit.core.annotation.CPDFAnnotation;
import com.compdfkit.tools.common.utils.animation.CFillScreenManager;
import com.compdfkit.tools.common.utils.animation.ConstraintSetUtils;
import com.compdfkit.tools.common.views.pdfproperties.CAnnotationType;
import com.compdfkit.tools.common.views.pdfview.CPreviewMode;

public class CAnnotSampleScreenManager {

    private AnnotationPdfSampleActivityBinding binding;

    private CFillScreenManager fillScreenManager = new CFillScreenManager();

    private ConstraintSet constraintSet = new ConstraintSet();

    private ConstraintSetUtils constraintSetUtils = new ConstraintSetUtils();

    private boolean isFillScreen;

    public void bind(AnnotationPdfSampleActivityBinding mainBinding) {
        this.binding = mainBinding;
        constraintSet.clone(binding.getRoot());
        fillScreenManager.bindRightToolViewList(binding.pdfView.slideBar);
        fillScreenManager.bindBottomToolViewList(binding.pdfView.indicatorView);
        fillScreenManager.bindBottomToolViewList(binding.annotationToolBar);
    }


    public void changeWindowStatus(CPreviewMode mode) {
        if (mode == CPreviewMode.Viewer) {
            fillScreenManager.removeToolView(binding.annotationToolBar);
            constraintSetUtils.hideFromBottom(constraintSet, binding.annotationToolBar);
        } else if (mode == CPreviewMode.Annotation) {
            fillScreenManager.bindBottomToolViewList(binding.annotationToolBar);
            constraintSetUtils.showFromBottom(constraintSet, binding.annotationToolBar);
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

    public void changeWindowStatus(CAnnotationType type) {
        if (type == CAnnotationType.INK) {
            fillScreenChange();
            fillScreenManager.bindTopToolView(binding.inkCtrlView);
            binding.inkCtrlView.setVisibility(View.VISIBLE);
        } else {
            if (isFillScreen){
                fillScreenChange();
            }
            binding.inkCtrlView.setVisibility(View.GONE);
            fillScreenManager.removeToolView(binding.inkCtrlView);
        }
    }

    public void changeWindowStatus(CPDFAnnotation.Type pdfType) {
        if (pdfType == CPDFAnnotation.Type.INK) {
            fillScreenChange();
            fillScreenManager.bindTopToolView(binding.inkCtrlView);
            binding.inkCtrlView.setVisibility(View.VISIBLE);
        } else {
            if (isFillScreen) {
                fillScreenChange();
            }
            binding.inkCtrlView.setVisibility(View.GONE);
            fillScreenManager.removeToolView(binding.inkCtrlView);
        }
    }

    public void fillScreenChange() {
        fillScreenManager.fillScreenChange(!isFillScreen);
        if (!isFillScreen) {
            //enter full screen
            constraintSetUtils.hideFromTop(constraintSet, binding.flTool);
            constraintSetUtils.hideFromBottom(constraintSet, binding.annotationToolBar);
            isFillScreen = true;
        } else {
            //enter normal state
            constraintSetUtils.showFromTop(constraintSet, binding.flTool);
            //show bottom annotationBar
            if (fillScreenManager.bottomToolViewList.contains(binding.annotationToolBar)) {
                constraintSetUtils.showFromBottom(constraintSet, binding.annotationToolBar);
            }else {
                constraintSetUtils.hideFromBottom(constraintSet, binding.annotationToolBar);
            }
            isFillScreen = false;
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }
}
