package com.compdfkit.docseditor;

import android.Manifest;
import android.os.Build;
import android.os.Bundle;
import android.view.View;

import androidx.activity.result.ActivityResultLauncher;

import com.compdfkit.docseditor.databinding.ActivityMainBinding;
import com.compdfkit.tools.common.basic.activity.CBasicPDFActivity;
import com.compdfkit.tools.common.utils.CFileUtils;
import com.compdfkit.tools.common.utils.CPermissionUtil;
import com.compdfkit.tools.common.utils.activitycontracts.CSelectPDFDocumentResultContract;
import com.compdfkit.tools.common.utils.dialog.CAlertDialog;
import com.compdfkit.tools.common.utils.task.CExtractAssetFileTask;
import com.compdfkit.tools.common.utils.window.CPopupMenuWindow;
import com.compdfkit.tools.common.views.pdfbota.CPDFBOTA;
import com.compdfkit.tools.common.views.pdfbota.CPDFBotaDialogFragment;
import com.compdfkit.tools.common.views.pdfbota.CPDFBotaFragmentTabs;
import com.compdfkit.tools.common.views.pdfview.CPDFIReaderViewCallback;
import com.compdfkit.tools.common.views.pdfview.CPreviewMode;
import com.compdfkit.tools.docseditor.pdfpageedit.CPDFPageEditDialogFragment;
import com.compdfkit.tools.viewer.pdfsearch.CSearchResultDialogFragment;
import com.compdfkit.ui.reader.CPDFReaderView;

import java.util.ArrayList;
import java.util.Arrays;

public class MainActivity extends CBasicPDFActivity {

    /**
     * assets folder pdf file
     */
    public static final String QUICK_START_GUIDE = "ComPDFKit_Annotations_Sample_File.pdf";
    ActivityMainBinding binding;
    CPageEditSampleScreenManager screenManager = new CPageEditSampleScreenManager();

    private ActivityResultLauncher<Void> selectDocumentLauncher = registerForActivityResult(new CSelectPDFDocumentResultContract(), uri -> {
        if (uri != null) {
            CFileUtils.takeUriPermission(this, uri);
            binding.pdfView.openPDF(uri);
            binding.pdfToolBar.selectMode(CPreviewMode.Viewer);
        }
    });

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        screenManager.bind(binding);
        initPDFView();
        initToolbarListener();
        initSearchBar();
    }

    private void setPreviewMode(CPreviewMode mode) {
        if (binding.pdfView.getCPdfReaderView() == null) {
            return;
        }
        binding.pdfToolBar.selectMode(mode);
        binding.pdfView.setViewMode(CPDFReaderView.ViewMode.VIEW);
        if (mode == CPreviewMode.Viewer) {

        } else {
            CPDFPageEditDialogFragment pageEditDialogFragment = CPDFPageEditDialogFragment.newInstance();
            pageEditDialogFragment.initWithPDFView(binding.pdfView);
            pageEditDialogFragment.setOnBackListener(() -> {
                setPreviewMode(CPreviewMode.Viewer);
            });
            pageEditDialogFragment.show(getSupportFragmentManager(),"fff");
        }
    }

    private void initPDFView() {
        binding.pdfView.setViewMode(CPDFReaderView.ViewMode.VIEW);
        resetContextMenu(binding.pdfView, CPreviewMode.Viewer);
        registerFormHelper(binding.pdfView);
        //Extract PDF files from the Android assets folder
        CExtractAssetFileTask.extract(this, QUICK_START_GUIDE, QUICK_START_GUIDE, (filePath) -> {
            binding.pdfView.openPDF(filePath);
            setPreviewMode(CPreviewMode.Viewer);
        });
        binding.pdfView.addReaderViewCallback(new CPDFIReaderViewCallback(){
            @Override
            public void onTapMainDocArea() {
                screenManager.fillScreenChange();
            }
        });
    }

    private void initToolbarListener() {
        binding.pdfToolBar.addModes(Arrays.asList(CPreviewMode.Viewer, CPreviewMode.PageEdit));
        binding.pdfToolBar.addAction(R.drawable.tools_ic_thumbnail, v -> {
            CPDFBotaDialogFragment botaDialogFragment = CPDFBotaDialogFragment.newInstance();
            botaDialogFragment.initWithPDFView(binding.pdfView);
            CPDFBotaFragmentTabs thumbnailTabs = new CPDFBotaFragmentTabs(CPDFBOTA.THUMBNAIL, getString(R.string.tools_thumbnails));
            ArrayList<CPDFBotaFragmentTabs> tabs = new ArrayList<>();
            tabs.add(thumbnailTabs);
            botaDialogFragment.setBotaDialogTabs(tabs);
            botaDialogFragment.show(getSupportFragmentManager(), "boTaDialogFragment");
        });
        binding.pdfToolBar.addAction(R.drawable.tools_ic_search, v -> {
            binding.pdfToolBar.setVisibility(View.GONE);
            binding.pdfSearchToolBar.setVisibility(View.VISIBLE);
            binding.pdfSearchToolBar.showKeyboard();
        });
        binding.pdfToolBar.addAction(R.drawable.tools_ic_bookmark, v -> {
            //Show a fragment of the PDF thumbnail and a dialog fragment of the PDF outline list.
            CPDFBotaDialogFragment botaDialogFragment = CPDFBotaDialogFragment.newInstance();
            botaDialogFragment.initWithPDFView(binding.pdfView);
            CPDFBotaFragmentTabs outlineTabs = new CPDFBotaFragmentTabs(CPDFBOTA.OUTLINE, getString(R.string.tools_outlines));
            CPDFBotaFragmentTabs bookmarks = new CPDFBotaFragmentTabs(CPDFBOTA.BOOKMARKS, getString(R.string.tools_bookmarks));
            ArrayList<CPDFBotaFragmentTabs> tabs = new ArrayList<>();
            tabs.add(outlineTabs);
            tabs.add(bookmarks);
            botaDialogFragment.setBotaDialogTabs(tabs);
            botaDialogFragment.show(getSupportFragmentManager(), "boTaDialogFragment");
        });
        binding.pdfToolBar.addAction(R.drawable.tools_ic_more, v -> {
            v.setSelected(true);
            //Show the PDF settings dialog fragment
            CPopupMenuWindow menuWindow = new CPopupMenuWindow(this);
            menuWindow.addItem(R.drawable.tools_ic_preview_settings, R.string.tools_view_setting, v1 -> {
                showDisplaySettings(binding.pdfView);
            });
            menuWindow.addItem(R.drawable.tools_ic_document_info, R.string.tools_document_info, v1 -> {
                showDocumentInfo(binding.pdfView);
            });
            menuWindow.addItem(R.drawable.tools_ic_share, R.string.tools_share, v1 -> {
                sharePDF(binding.pdfView);
            });
            menuWindow.addItem(R.drawable.tools_ic_new_file, R.string.tools_open_document, v1 -> {
                if (CPermissionUtil.hasStoragePermissions(this)) {
                    selectDocument();
                } else {
                    requestStoragePermissions();
                }
            });
            menuWindow.setOnDismissListener(() -> v.setSelected(false));
            menuWindow.showAsDropDown(v);
        });
        binding.pdfToolBar.setPreviewModeChangeListener((mode) -> {
            setPreviewMode(mode);
        });
    }

    private void requestStoragePermissions(){
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU){
            CPermissionUtil.openManageAllFileAppSettings(this);
        }else {
            multiplePermissionResultLauncher.launch(STORAGE_PERMISSIONS, result -> {
                if (CPermissionUtil.hasStoragePermissions(this)) {
                    selectDocument();
                }else {
                    if (!CPermissionUtil.shouldShowRequestPermissionRationale(this, Manifest.permission.WRITE_EXTERNAL_STORAGE)){
                        showPermissionsRequiredDialog();
                    }
                }
            });
        }
    }

    private void initSearchBar() {
        binding.pdfSearchToolBar.initWithPDFView(binding.pdfView);
        binding.pdfSearchToolBar.onSearchQueryResults(list -> {
            CSearchResultDialogFragment searchResultDialog = new CSearchResultDialogFragment();
            searchResultDialog.show(getSupportFragmentManager(), "searchResultDialogFragment");
            searchResultDialog.setSearchTextInfos(list);
            searchResultDialog.setOnClickSearchItemListener(clickItem -> {
                binding.pdfView.getCPdfReaderView().setDisplayPageIndex(clickItem.page);
                binding.pdfView.getCPdfReaderView().getTextSearcher().searchBegin(clickItem.page, clickItem.textRangeIndex);
                searchResultDialog.dismiss();
            });
        });

        binding.pdfSearchToolBar.setExitSearchListener(() -> {
            binding.pdfToolBar.setVisibility(View.VISIBLE);
            binding.pdfSearchToolBar.setVisibility(View.GONE);
        });
    }

    private void selectDocument() {
        if (binding.pdfView.getCPdfReaderView().getPDFDocument() == null){
            selectDocumentLauncher.launch(null);
            return;
        }
        if (!binding.pdfView.getCPdfReaderView().getPDFDocument().hasChanges()){
            selectDocumentLauncher.launch(null);
            return;
        }
        CAlertDialog alertDialog = CAlertDialog.newInstance(getString(com.compdfkit.tools.R.string.tools_save_title), getString(com.compdfkit.tools.R.string.tools_save_message));
        alertDialog.setConfirmClickListener(v -> {
            //save pdf document
            binding.pdfView.savePDF((filePath, pdfUri) -> {
                alertDialog.dismiss();
                selectDocumentLauncher.launch(null);
            },e -> {
                alertDialog.dismiss();
                selectDocumentLauncher.launch(null);
            });
        });
        alertDialog.setCancelClickListener(v -> {
            alertDialog.dismiss();
            selectDocumentLauncher.launch(null);
        });
        alertDialog.show(getSupportFragmentManager(), "alertDialog");
    }

    @Override
    public void onBackPressed() {
        if (binding.pdfView != null) {
            binding.pdfView.savePDF((filePath, pdfUri) -> super.onBackPressed(), e -> super.onBackPressed());
        }else {
            super.onBackPressed();
        }
    }
}